@@ -31,16 +31,44 @@ def generate_gif(im1, im2):
     return bio
 
 
-def overlay_images(background, foreground):
-    foreground = foreground.resize(
-        (round(background.size[0]), round(background.size[1])))
-    background.paste(foreground, (0, 0), foreground)
+def overlay_images(background, foreground, x_position="left", y_position="up", resize=True):
+    if resize:
+        foreground = background.resize(
+            (round(foreground.size[0]), round(foreground.size[1])))
+    
+    if x_position=="left":
+        x_coordinate = 0
+    elif x_position=="right":
+        x_coordinate = background.size[0] - foreground.size[0]
+    elif x_position=="middle":
+        x_coordinate = background.size[0]/2 - foreground.size[0]/2
+
+    if y_position =="up":
+        y_coordinate = 0
+    elif y_position =="middle":
+        y_coordinate = background.size[1]/2 - foreground.size[1]/2
+    elif y_position == "bottom":
+        y_coordinate = background.size[1] - foreground.size[1]
+
+
+    background.paste(foreground, (x_coordinate, y_coordinate), foreground)
     bio = BytesIO()
     bio.name = 'image.png'
     background.save(bio, 'PNG')
     bio.seek(0)
     return bio
 
+def telegram_eval_image_overlay(update: Update, context: CallbackContext, picture):
+    im_bytes = update.message.photo[-1].get_file().download_as_bytearray()
+
+    im_file = BytesIO(im_bytes)  # convert image to file-like object
+    im1 = Image.open(im_file)   # img is now PIL Image object
+    im2 = Image.open('assets/' + picture)
+
+    new_im = overlay_images(im1, im2)
+
+    update.message.reply_photo(new_im)
+
 
 def telegram_eval_gif_generation(update: Update, context: CallbackContext, picture):
     im_bytes = update.message.photo[-1].get_file().download_as_bytearray()
@@ -107,6 +135,7 @@ def whatsapp_eval_gif_generation(client, update: WhatsAppUpdate, context, pictur
 
 
 telegram_action_functions = {"eval_gif_generation": telegram_eval_gif_generation,
+                             "eval_image_overlay": telegram_eval_image_overlay
                              }
 
 whatsapp_action_functions = {"eval_gif_generation": whatsapp_eval_gif_generation,
