@@ -7,7 +7,7 @@ from typing import List
 import requests as req
 import yaml
 from digitalguide.pattern import (EMOJI_PATTERN, JA_PATTERN, NEIN_PATTERN,
-                                  WEITER_PATTERN, WOHIN_PATTERN)
+                                  WEITER_PATTERN, WOHIN_PATTERN, ZURUECK_PATTERN)
 from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
 from requests.exceptions import Timeout
 
@@ -41,6 +41,9 @@ def read_state_yml(filename, actions={}, prechecks: List = []):
                     elif handler["regex"] == "NEIN_PATTERN":
                         newHandler = MessageHandler(RegexFilter(
                             NEIN_PATTERN), actions[handler["action"]])
+                    elif handler["regex"] == "ZURUECK_PATTERN":
+                        newHandler = MessageHandler(RegexFilter(
+                            ZURUECK_PATTERN), actions[handler["action"]])
                     else:
                         newHandler = MessageHandler(RegexFilter(
                             handler["regex"]), actions[handler["action"]])
